@@ -85,6 +85,9 @@ def query(q, id=None, tries=calltries, cache_inc=False):
         if reqStatus == 100:
             res = limutils.build_dataframe(root[0])
             return res
+        elif reqStatus == 110:
+            logging.info('Invalid query')
+            raise Exception(root.attrib['statusMsg'])
         elif reqStatus == 130:
             logging.info('No data')
         elif reqStatus == 200:
@@ -157,7 +160,7 @@ def curve_formula(formula, column='Close', curve_dates=None):
         res = curve(matches, column=column, curve_formula=formula)
     else:
         dfs, res = [], None
-        if not isinstance(curve_dates, list):
+        if not isinstance(curve_dates, list) and not isinstance(curve_dates, tuple):
             curve_dates = [curve_dates]
         for d in curve_dates:
             rx = curve(matches, column=column, curve_dates=d, curve_formula=formula)
@@ -204,6 +207,7 @@ def relations(symbol, show_children=False, show_columns=False, desc=False, date_
     :return:
     """
     if isinstance(symbol, list) or isinstance(symbol, tuple):
+        symbol = set(symbol)
         symbol = ','.join(symbol)
     uri = '%s/%s' % (lim_schema_url, symbol)
     params = {
@@ -257,7 +261,6 @@ def get_symbol_contract_list(symbol, monthly_contracts_only=False):
     :param symbol:
     :return:
     """
-
     resp = relations(symbol, show_children=True)
     if resp is not None:
         children = resp.loc['children']
